==> mx-codecs_23.7.02.tar.xz: mx-codecs/translations/mx-codecs_nl_BE.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl_BE">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>MX Codecs Installer</source>
        <translation>MX Codecs Installeerder</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="27"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;justify&quot;&gt;This application allows you to install restricted codecs that permit advanced video and audio functions.&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;In some jurisdictions, their distribution may be limited. Please check the regulations in your area. &lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;br/&gt;&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Do you assume legal responsibility for downloading these codecs?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;justify&quot;&gt;Deze applicatie staat u toe gelimiteerde codecs te gebruiken die geavanceerde video en audio functies toestaan.&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;In sommige jurisdicties kan hun distributie beperkt zijn. Kijk alstublieft de regelgeving in uw gebied na.&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;br/&gt;&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Neemt u de legale verantwoordelijkheid voor het downloaden van deze codecs?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="44"/>
        <source>Downloading codecs files</source>
        <translation>Codecs bestanden downloaden</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="100"/>
        <source>Cancel any changes then quit</source>
        <translation>Iedere verandering ongedaan maken, dan afsluiten</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="103"/>
        <source>Cancel</source>
        <translation>Ongedaan maken</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="110"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="129"/>
        <source>Begin codec download and installation</source>
        <translation>Begin codec download en installatie</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="132"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="193"/>
        <source>About this application</source>
        <translation>Over deze applicatie</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="196"/>
        <source>About...</source>
        <translation>Over...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="203"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="232"/>
        <source>Display help </source>
        <translation>Toon help</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="235"/>
        <source>Help</source>
        <translation>Help</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="242"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="184"/>
        <location filename="../mainwindow.cpp" line="191"/>
        <location filename="../mainwindow.cpp" line="200"/>
        <location filename="../mainwindow.cpp" line="226"/>
        <source>&lt;b&gt;Running command...&lt;/b&gt;&lt;p&gt;</source>
        <translation>&lt;b&gt;Commando uitvoeren...&lt;/b&gt;&lt;p&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="110"/>
        <location filename="../mainwindow.cpp" line="151"/>
        <location filename="../mainwindow.cpp" line="171"/>
        <location filename="../mainwindow.cpp" line="214"/>
        <location filename="../mainwindow.cpp" line="223"/>
        <location filename="../mainwindow.cpp" line="246"/>
        <location filename="../mainwindow.cpp" line="287"/>
        <source>Error</source>
        <translation>Foutmelding</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="214"/>
        <source>Cannot connect to the download site</source>
        <translation>Kan geen verbinding maken met de download site</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="126"/>
        <source>Error downloading %1</source>
        <translation>Download fout %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="111"/>
        <source>Internet is not available, won&apos;t be able to download the list of packages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="152"/>
        <source>There was an error writing file: %1. Please check if you have enough free space on your drive</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="171"/>
        <source>Could not create temp directory. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="184"/>
        <source>downloading Packages.gz from &apos;main&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="191"/>
        <source>downloading Packages.gz from &apos;non-free&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="200"/>
        <source>downloading Packages.gz from i386 &apos;main&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="206"/>
        <source>&lt;b&gt;Download Finished.&lt;/b&gt;</source>
        <translation>&lt;b&gt;Download  klaar.&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="223"/>
        <source>Cannot connect find %1 package</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="243"/>
        <source>Installing downloaded files</source>
        <translation>Gedownloade bestanden installeren</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="246"/>
        <source>No downloaded *.debs files found.</source>
        <translation>Geen gedownloade *.deb bestanden gevonden.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="264"/>
        <source>&lt;b&gt;Installing...&lt;/b&gt;&lt;p&gt;</source>
        <translation>&lt;b&gt;Installeren...&lt;/b&gt;&lt;p&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="266"/>
        <source>Error installing %1</source>
        <translation>Fout bij  het installeren %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="271"/>
        <source>Fix missing dependencies...</source>
        <translation>Herstel ontbrekende afhankelijkheden...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="274"/>
        <source>Error running %1 command</source>
        <translation>Fout met uitvoeren %1 commando</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="279"/>
        <source>&lt;b&gt;Installation process has finished&lt;/b&gt;</source>
        <translation>&lt;b&gt;Installatieproces is beëindigd&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="283"/>
        <source>Finished</source>
        <translation>Voltooid</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="284"/>
        <source>Codecs files have been downloaded and installed successfully.</source>
        <translation>De codecs bestanden zijn gedownload en succesvol geïnstalleerd.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="287"/>
        <source>Process finished. Errors have occurred during the installation.</source>
        <translation>Proces beëindigd. Er hebben zich fouten voorgedaan tijdens de installatie.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="296"/>
        <source>About MX Codecs</source>
        <translation>Over MX Codecs</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="302"/>
        <source>%1 License</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="313"/>
        <source>%1 Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MX Codecs</source>
        <translation type="vanished">MX Codecs</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="297"/>
        <source>Version: </source>
        <translation>Versie:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="299"/>
        <source>Simple codecs downloader for MX Linux</source>
        <translation>Eenvoudige codecs downloader voor MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="301"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <source>License</source>
        <translation type="vanished">Licentie</translation>
    </message>
    <message>
        <source>Changelog</source>
        <translation type="vanished">Changelog</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="vanished">&amp;Sluiten</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <source>Unable to get exclusive lock</source>
        <translation type="vanished">Niet in staat om exclusief slot te verkrijgen</translation>
    </message>
    <message>
        <source>Another package management application (like Synaptic or apt-get), is already running. Please close that application first</source>
        <translation type="vanished">Een ander pakketbeheerprogramma (zoals Synaptic of apt-get) is reeds in gebruik. Sluit aub eerst dat programma</translation>
    </message>
    <message>
        <source>You must run this program as root.</source>
        <translation type="vanished">U dient deze toepassing als &apos;root&apos; uit te voeren.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="52"/>
        <source>License</source>
        <translation type="unfinished">Licentie</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="53"/>
        <location filename="../about.cpp" line="62"/>
        <source>Changelog</source>
        <translation type="unfinished">Changelog</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="54"/>
        <source>Cancel</source>
        <translation type="unfinished">Ongedaan maken</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="74"/>
        <source>&amp;Close</source>
        <translation type="unfinished">&amp;Sluiten</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="66"/>
        <source>Error</source>
        <translation type="unfinished">Foutmelding</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="67"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="77"/>
        <source>Unable to get exclusive lock</source>
        <translation type="unfinished">Niet in staat om exclusief slot te verkrijgen</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="78"/>
        <source>Another package management application (like Synaptic or apt-get), is already running. Please close that application first</source>
        <translation type="unfinished">Een ander pakketbeheerprogramma (zoals Synaptic of apt-get) is reeds in gebruik. Sluit aub eerst dat programma</translation>
    </message>
</context>
</TS>

==> mx-codecs_23.7.03.tar.xz: mx-codecs/translations/mx-codecs_nl_BE.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.0" language="nl_BE">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>MX Codecs Installer</source>
        <translation>MX Codecs Installeerder</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="27"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;justify&quot;&gt;This application allows you to install restricted codecs that permit advanced video and audio functions.&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;In some jurisdictions, their distribution may be limited. Please check the regulations in your area. &lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;br/&gt;&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Do you assume legal responsibility for downloading these codecs?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;justify&quot;&gt;Deze applicatie staat u toe gelimiteerde codecs te gebruiken die geavanceerde video en audio functies toestaan.&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;In sommige jurisdicties kan hun distributie beperkt zijn. Kijk alstublieft de regelgeving in uw gebied na.&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;br/&gt;&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Neemt u de legale verantwoordelijkheid voor het downloaden van deze codecs?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="44"/>
        <source>Downloading codecs files</source>
        <translation>Codecs bestanden downloaden</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="94"/>
        <source>Cancel any changes then quit</source>
        <translation>Iedere verandering ongedaan maken, dan afsluiten</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="97"/>
        <location filename="../mainwindow.cpp" line="268"/>
        <source>Cancel</source>
        <translation>Ongedaan maken</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="104"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="117"/>
        <source>Begin codec download and installation</source>
        <translation>Begin codec download en installatie</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="120"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="175"/>
        <source>About this application</source>
        <translation>Over deze applicatie</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="178"/>
        <source>About...</source>
        <translation>Over...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="185"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="214"/>
        <source>Display help </source>
        <translation>Toon help</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="217"/>
        <source>Help</source>
        <translation>Help</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="224"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="105"/>
        <location filename="../mainwindow.cpp" line="112"/>
        <location filename="../mainwindow.cpp" line="120"/>
        <location filename="../mainwindow.cpp" line="128"/>
        <location filename="../mainwindow.cpp" line="137"/>
        <location filename="../mainwindow.cpp" line="144"/>
        <location filename="../mainwindow.cpp" line="153"/>
        <location filename="../mainwindow.cpp" line="161"/>
        <source>&lt;b&gt;Running command...&lt;/b&gt;&lt;p&gt;</source>
        <translation>&lt;b&gt;Commando uitvoeren...&lt;/b&gt;&lt;p&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="108"/>
        <location filename="../mainwindow.cpp" line="124"/>
        <location filename="../mainwindow.cpp" line="131"/>
        <location filename="../mainwindow.cpp" line="140"/>
        <location filename="../mainwindow.cpp" line="146"/>
        <location filename="../mainwindow.cpp" line="157"/>
        <location filename="../mainwindow.cpp" line="164"/>
        <location filename="../mainwindow.cpp" line="193"/>
        <location filename="../mainwindow.cpp" line="246"/>
        <source>Error</source>
        <translation>Foutmelding</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="109"/>
        <location filename="../mainwindow.cpp" line="125"/>
        <location filename="../mainwindow.cpp" line="141"/>
        <location filename="../mainwindow.cpp" line="158"/>
        <source>Cannot connect to the download site</source>
        <translation>Kan geen verbinding maken met de download site</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="115"/>
        <location filename="../mainwindow.cpp" line="132"/>
        <location filename="../mainwindow.cpp" line="147"/>
        <location filename="../mainwindow.cpp" line="165"/>
        <source>Error downloading %1</source>
        <translation>Download fout %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="170"/>
        <source>&lt;b&gt;Download Finished.&lt;/b&gt;</source>
        <translation>&lt;b&gt;Download  klaar.&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="189"/>
        <source>Installing downloaded files</source>
        <translation>Gedownloade bestanden installeren</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="194"/>
        <source>No downloaded *.debs files found.</source>
        <translation>Geen gedownloade *.deb bestanden gevonden.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="207"/>
        <source>&lt;b&gt;Installing...&lt;/b&gt;&lt;p&gt;</source>
        <translation>&lt;b&gt;Installeren...&lt;/b&gt;&lt;p&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="220"/>
        <source>Error installing %1</source>
        <translation>Fout bij  het installeren %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="224"/>
        <source>Fix missing dependencies...</source>
        <translation>Herstel ontbrekende afhankelijkheden...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="226"/>
        <source>Error running %1 command</source>
        <translation>Fout met uitvoeren %1 commando</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="238"/>
        <source>&lt;b&gt;Installation process has finished&lt;/b&gt;</source>
        <translation>&lt;b&gt;Installatieproces is beëindigd&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="242"/>
        <source>Finished</source>
        <translation>Voltooid</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="243"/>
        <source>Codecs files have been downloaded and installed successfully.</source>
        <translation>De codecs bestanden zijn gedownload en succesvol geïnstalleerd.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="247"/>
        <source>Process finished. Errors have occurred during the installation.</source>
        <translation>Proces beëindigd. Er hebben zich fouten voorgedaan tijdens de installatie.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="261"/>
        <source>About MX Codecs</source>
        <translation>Over MX Codecs</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="262"/>
        <source>MX Codecs</source>
        <translation>MX Codecs</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="262"/>
        <source>Version: </source>
        <translation>Versie:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="264"/>
        <source>Simple codecs downloader for MX Linux</source>
        <translation>Eenvoudige codecs downloader voor MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="265"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="266"/>
        <source>License</source>
        <translation>Licentie</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="267"/>
        <location filename="../mainwindow.cpp" line="277"/>
        <source>Changelog</source>
        <translation>Changelog</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="285"/>
        <source>&amp;Close</source>
        <translation>&amp;Sluiten</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>Unable to get exclusive lock</source>
        <translation>Niet in staat om exclusief slot te verkrijgen</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="54"/>
        <source>Another package management application (like Synaptic or apt-get), is already running. Please close that application first</source>
        <translation>Een ander pakketbeheerprogramma (zoals Synaptic of apt-get) is reeds in gebruik. Sluit aub eerst dat programma</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="67"/>
        <source>You must run this program as root.</source>
        <translation>U dient deze toepassing als &apos;root&apos; uit te voeren.</translation>
    </message>
</context>
</TS>
